<?php
/**
 * This file implements the Rich Tags Plug-in 0.4
 * intended for use with b2evolution 2.x
 *
 * This plug-in is intended to implement Technorati's tags system.
 *
 * Released under GNU GPL License - {@link http://www.gnu.org/copyleft/gpl.html}
 * @copyright (c)2005 by kwa - {http://blog.lesperlesduchat.com/dev.php}
 *
 * @author kwa (http://unearaigneeauplafond.be)
 * Further hacked by Rob Crowther (http://www.boogdesign.com/)
 *
 * @package plugins
 *
*/
if( !defined('EVO_MAIN_INIT') ) die( 'Please, do not access this page directly.' );

/**
 * Description & Keywords Plug-in
 *
 * This plug-in converts relative path of links and images to full path.
 *
 * @package plugins
 */
class RichTags_plugin extends Plugin
{
	/**
	 * Variables below MUST be overriden by plugin implementations,
	 * either in the subclass declaration or in the subclass constructor.
	 */
	var $name = 'Rich Tags';
	var $code = 'b2eRchTgs';
	var $priority = 100;
	var $version = '0.4';
	var $author = 'kwa';
	var $help_url = 'http://forums.b2evolution.net/viewtopic.php?t=6038';  // empty URL defaults to manual wiki, in this case: http://manual.b2evolution.net/Plugins/test_plugin';
	
	/*
	 * These variables MAY be overriden.
	 */
	var $apply_rendering = 'stealth';
	var $number_of_installs = 1;
	var $group = 'rendering';
	
	var $short_desc;
	var $long_desc;


	/**
	 * Init
	 */
	function PluginInit( & $params )
	{
        $this->short_desc = T_( 'Implements rel-tag.' );
        $this->long_desc = T_( 'This plug-in adds rel-tag  ( see http://microformats.org/wiki/rel-tag ) links to tagged posts, choose from any or all of Technorati, Delicious or Flickr. (This plug-in is intended for b2evolution versions 2.x.)' );
    }
	/**
	 * Get the settings that the plugin can use.
	 */
   function GetDefaultSettings( & $params )
    {
      $r = array(
         'technorati_tags' => array(
               'label' => 'Enable Technorati Tags',
               'type' => 'checkbox',
               'defaultvalue' => 1,
                'note' => 'Inserts links to technorati tag pages, you should also add a CSS rule for either .tags (generic) or technorati_tags (specific)',
                ),
          'delicious_tags' => array(
               'label' => 'Enable Delicious Tags',
               'type' => 'checkbox',
               'defaultvalue' => 0,
                'note' => 'Inserts links to delicious tag pages, you should also add a CSS rule for either .tags (generic) or delicious_tags (specific)',
                ),
          'flickr_tags' => array(
               'label' => 'Enable Flickr Tags',
               'type' => 'checkbox',
               'defaultvalue' => 0,
                'note' => 'Inserts links to flickr tag pages, you should also add a CSS rule for either .tags (generic) or flickr_tags (specific)',
                ),
          'twitter_tags' => array(
               'label' => 'Enable Twitter Tags',
               'type' => 'checkbox',
               'defaultvalue' => 0,
                'note' => 'Inserts links to twitter tag searches, you should also add a CSS rule for either .tags (generic) or twitter_tags (specific)',
                ),
        );
      return $r;
    }
    /**
     * Add tags to content
     *
     * {@internal RichTags_Rendererplugin::render(-)}
     *
     * @param string Content to render (by reference) / rendered content.
     * @param array  Array of tags to render.
     * @param string Text to write at the beginning of all the tags.
     * @param string Text to write at the end of all the tags.
     * @param string Link to the tagging system.
     * @param string Additional link attributed (new window, rel attribute, etc.).
     * @return boolean This function returns true when at least one tag has been added. false otherwise.
    */
	function addTags( & $content, $Tags, $Before, $After, $Link, $LinkAttributes )
	{
		$IsFirst = true;
		$ContentTags = '';
		foreach( $Tags as $Tag )
		{
			if( strlen( $Tag ) > 1 )
			{
				if( $IsFirst === true )
					$IsFirst = false;
				else
					$ContentTags .= ' &bull; ';
				$TagToDisplay = htmlentities( str_replace( '+', ' ', $Tag ) );
				$ContentTags .= '<a '.$LinkAttributes.' href="'.$Link.urlencode(utf8_encode( $Tag )).'">'.$TagToDisplay.'</a>';
			}
		}
		if( strlen( $ContentTags ) > 1 )
		{
			// Tags added
			$content .= $Before.$ContentTags.$After;
			return true;
		}
		else
		{
			// No tags added
			return false;
		}
	} // addTags


	/**
	 * Perform rendering
	 */
	function RenderItemAsHtml( & $params )
	{
		$content = & $params['data'];
		
		$AddedAtLeastOneTag = false;

		if( preg_match( '/<!--tags?[\s]+([^>]*)[\s]*--\>/si', $content, $Matches ) )
		{
			if( preg_match_all( '/([^\s]*)[\s]*/si', $Matches[ 1 ], $Matches ) )
			{
				// Sort using human-like alphabetic order
				natcasesort( $Matches[ 1 ] );

				// Add miscellaneous tagging systems
                if ($this->Settings->get( 'technorati_tags' ) == 1) {
    				$AddedAtLeastOneTag |= $this->addTags( $content, $Matches[ 1 ], '<div class="tags technorati_tags"><strong>Technorati tags for this post&nbsp;:</strong> ', '</div>', 'http://technorati.com/tag/', ' rel="tag"' );
                }
                if ($this->Settings->get( 'delicious_tags' ) == 1) {
    				$AddedAtLeastOneTag |= $this->addTags( $content, $Matches[ 1 ], '<div class="tags delicious_tags"><strong>Delicious tags for this post&nbsp;:</strong> ', '</div>', 'http://delicious.com/tag/', ' rel="tag"' );
                }
                if ($this->Settings->get( 'flickr_tags' ) == 1) {
    				$AddedAtLeastOneTag |= $this->addTags( $content, $Matches[ 1 ], '<div class="tags flickr_tags"><strong>Flickr tags for this post&nbsp;:</strong> ', '</div>', 'http://www.flickr.com/photos/tags/', ' rel="tag"' );
                }
                if ($this->Settings->get( 'twitter_tags' ) == 1) {
    				$AddedAtLeastOneTag |= $this->addTags( $content, $Matches[ 1 ], '<div class="tags twitter_tags"><strong>Twitter tags for this post&nbsp;:</strong> ', '</div>', 'http://search.twitter.com/search?tag=', ' rel="tag"' );
                }
            }
		
			// bug fix?
			$content = preg_replace( '/<!--tags?[\s]+([^>]*)[\s]*--\>/si', '', $content );		
		}

		// No tags found?
		global $preview;
		if( isset( $preview ) && $preview != false && is_logged_in() && !$AddedAtLeastOneTag )
		{
			// Display a warning message
			$content .= '<div style="margin:0;padding:16px;color:black;border:solid 4px red;"><p>Tags are missing. To insert a tag, write the following (X)HTML code in your post:</p><blockquote><p><code>&lt;!--tags keyword1 keyword2 keywords3+keywords4 keyword5--&gt;</code></p></blockquote></div>';
		}
    }
	/**
	 * Perform rendering
	 */
	/*
	function RenderItemAsXml( & $params )
	{
		RenderItemAsHtml( $param );
	}
	*/
    function PluginSettingsUpdateAction()
    {
      global $DB;
      $DB->query('DELETE FROM T_items__prerendering WHERE 1');
      $this->msg( sprintf( T_('Removed %d cached entries.'), $DB->rows_affected ), 'success' );
    }
    /**
	 * Event handler: Called when displaying editor buttons.
	 *
	 * @see Plugin::AdminDisplayEditorButton()
	 * @param array Associative array of parameters
	 * @return boolean did we display ?
	 */
	function AdminDisplayEditorButton( & $params )
	{
		?><script language="JavaScript" type="text/javascript">
function WriteTag(){
			document.getElementById('itemform_post_content').value += "<!--tags MyTag My+Tag -->";
}
</script><input type="button" id="b2eRchTgs_button" value="Rich Tags" onclick="WriteTag()" /><?php
		return true;
	}
}
/*
You're probably going to want some CSS like this in your template stylesheet:
.tags {
	margin: 0;
	padding: 0.1em;
	font-size:0.7em;
	border: 1px dotted #1e8400;
}
a[rel~="tag"] { 
	color: #333;
	font-weight: 600;
	text-decoration: none;
}
a[rel~="tag"]:hover { 
	color: #366;
	text-decoration: underline;
}
.tags + .tags {
	margin-top: 0.1em;
}
.technorati_tags {
	border: 1px dotted #1e8400;
}
.delicious_tags {
	border: 1px dotted #1462C1;
}
.flickr_tags {
	border: 1px dotted #ff0084;
}
.twitter_tags {
	border: 1px dotted #33ccff;
}
.delicious_tags a:hover { 
	color: #36c;
}
.flickr_tags a:hover { 
	color: #f09;
}
.twitter_tags a:hover { 
	color: #3cf;
}
*
/*
 nolog */
?>
